/**
 * @(#)CustomCodePanel.java 1.0 99/09/14
 * 
 * Use this class as a starting point for creating your own custom code action.
 * 
 */

package com.zerog.ia.customcode.util;		// you should change this to your own package location

import com.zerog.ia.api.pub.*;
import java.util.StringTokenizer;
import java.awt.*;
import java.net.*;
import java.io.*;

/**
 * CustomCodeActionTemplate.java
 * 
 * Use this class as a starting point for creating your own custom code action.
 * 
 */
public class FullScreenImageAction extends CustomCodeAction
{
	/**
	 *  This is the method that is called at install-time.  The InstallerProxy
	 *  instance provides methods to access information in the installer,
	 *  set status, and control flow.
	 */
	public void install( InstallerProxy ip ) throws InstallException
	{
		final String Gradient=ip.substitute("$FSBGI_GRADIENT$");
		final String ImageInfo=ip.substitute("$FSBGI_IMAGE$");
		
		// if either of the variables not set tell the user so.
		
		if ( Gradient.equals("") || ImageInfo.equals(""))
		{
			System.out.println("One or more of the variables not set! I won't work as expected...");
		} 
		
		// we use an anonymous inner class so that we can override it's paint method.
		String OS=System.getProperty("os.name");
		System.out.println(OS);
		if ((OS.indexOf("Windows")>=0) || (OS.indexOf("Mac")>=0))
		{
			BigFrame=new Window(new Frame());
			System.out.println("We did a Window");
		}
		else
		{
			BigFrame=new Frame();
			System.out.println("We did a Frame");
		}
		Panel BigPan=new Panel()
		{
			public void paint(Graphics g)
			{
				// set variable to default values
				Graphics2D g2=(Graphics2D)g;
				GradientPaint gp;
				Rectangle rect=new Rectangle(0,0,d.width,d.height);
				float width=(d.width/256)+1.0f;
				float height=(d.height/256)+1.0f;
				int ColSeg[]={1,0,0,0,0,0,0};
				float RStep=0,BStep=0,GStep=0;
				int a=0,RStart=0,GStart=0,BStart=0;
				int ImageMode=3,pWidth=0,pHeight=0;
				
				// read the color values and mode of the gradient if FSBGI_GRADIENT set properly.
				
				if (!Gradient.equals(""))
				{
					StringTokenizer st=new StringTokenizer(Gradient,",");
					while (st.hasMoreTokens())
					{
						ColSeg[a]=Integer.parseInt(st.nextToken());
						a++;
					}
				}
				
				// read the image mode and get the image if FSBGI_IMAGE set properly.
				
				System.out.println("Reading image info");
				if (!ImageInfo.equals(""))
				{
					StringTokenizer sr=new StringTokenizer(ImageInfo,",");
					ImageMode=Integer.parseInt(sr.nextToken());
					
					// get image only if the ImageMode variable tells us to.
					
					System.out.println(ImageMode+"");
					if (ImageMode>=2)
					{
						imageURL=ClassLoader.getSystemResource(sr.nextToken());
						picture=Toolkit.getDefaultToolkit().getImage(imageURL);
					}	
				}
				
				// set up the increment values for displaying the gradient
				
				RStep=((float)(ColSeg[4]-ColSeg[1]))/255;
				GStep=((float)(ColSeg[5]-ColSeg[2]))/255;
				BStep=((float)(ColSeg[6]-ColSeg[3]))/255;
				RStart=ColSeg[1];
				GStart=ColSeg[2];
				BStart=ColSeg[3];
				
				
				// Now based on the initial parameter we decide what direction to show gradient in.
					
				switch (ColSeg[0])
				{
				case 1:
					// Display no gradient, set background to param 2 - 4.
					System.out.println("Setting background color...");
					setBackground(new Color(ColSeg[1],ColSeg[2],ColSeg[3]));
					break;
				case 2:
					// Display gradient top to bottom, params 2 - 4 = start color, 5 -7 end color. 
					System.out.println("Displaying Gradient top to bottom...");
					gp=new GradientPaint(d.width/2,0,new Color(ColSeg[1],ColSeg[2],ColSeg[3]),d.width/2,d.height,new Color(ColSeg[4],ColSeg[5],ColSeg[6]),true);
					g2.setPaint(gp);
					rect.setFrame(0,0,d.width,d.height);
					g2.fill(rect);
					break;
				case 3:
					// Display gradient bottom to top, colors as in case 1.
					System.out.println("Displaying Gradient bottom to top...");
					gp=new GradientPaint(d.width/2,0,new Color(ColSeg[4],ColSeg[5],ColSeg[6]),d.width/2,d.height,new Color(ColSeg[1],ColSeg[2],ColSeg[3]),true);
					g2.setPaint(gp);
					rect.setFrame(0,0,d.width,d.height);
					g2.fill(rect);
					break;
				case 4:
					// Display gradient left to right. colors as in case 1.
					System.out.println("Displaying Gradient left to right..."); 
					gp=new GradientPaint(0,d.height/2,new Color(ColSeg[1],ColSeg[2],ColSeg[3]),d.width,d.height/2,new Color(ColSeg[4],ColSeg[5],ColSeg[6]),true);
					g2.setPaint(gp);
					rect.setFrame(0,0,d.width,d.height);
					g2.fill(rect); 
					break;
				case 5:
					// Display gradient right to left. colors as in case 1.
					System.out.println("Displaying Gradient right to left...");
					gp=new GradientPaint(0,d.height/2,new Color(ColSeg[4],ColSeg[5],ColSeg[6]),d.width,d.height/2,new Color(ColSeg[1],ColSeg[2],ColSeg[3]),true);
					g2.setPaint(gp);
					rect.setFrame(0,0,d.width,d.height);
					g2.fill(rect); 
					break;
				default:
					// Improper value was set for mode.
					System.out.println("Illegal mode parameter specified!\n Can't display gradient!");
					break;
				}
				
				// We get the width and heoght of the picture only if the mode variable says that there
				// is a picture.
				
				if (ImageMode>=2)
				{
					pWidth=picture.getWidth(this);
					pHeight=picture.getHeight(this);
				}
				
				//Now based on ImageMode we decide if and how to display the image.
				
				switch (ImageMode)
				{
				case 1:
					//Don't display an image.
					System.out.println("You chose not to show an image...");
					break;
				case 2:
					//Stretch gthe image to fill the screen.
					System.out.println("Streching image to fill screen...");
					g.drawImage(picture,0,0,d.width,d.height,this);
					break;
				case 3:
					//Show image, over gradient, in upper left.
					System.out.println("Displaying image in upper left corner...");
					g.drawImage(picture,0,0,this);
					break;
				case 4:
					//Show image, over gradient, in upper right.
					System.out.println("Displaying image in upper right corner...");
					g.drawImage(picture,d.width-pWidth,0,this);
					break;
				case 5:
					//Show image, over gradient, in lower left.
					System.out.println("Displaying image in lower left corner...");
					g.drawImage(picture,0,d.height-pHeight,this);
					break;
				case 6:
					//Show image, over gradient, in lower right.
					System.out.println("Displaying image in lower right corner...");
					g.drawImage(picture,d.width-pWidth,d.height-pHeight,this);
					break;
				case 7:
					//Show image, over gradient, in center.
					System.out.println("Displaying image in center...");
					g.drawImage(picture,(d.width/2)-(pWidth/2),(d.height/2)-(pHeight/2),this);
					break;
				case 8:
					//Tile image to fill screen.
					System.out.println("Tiling image...");
					int xlimit=(int)d.width/pWidth;
					int ylimit=(int)d.height/pHeight;
					if((d.width%pWidth)!=0)
						xlimit++;
					if((d.height%pHeight)!=0)
						ylimit++;	
					for(int y=0;y<ylimit;y++)
					{
						for(int x=0;x<xlimit;x++)
						{
							g.drawImage(picture,x*pWidth,y*pHeight,this);
						}
					}
				default:
					//Improper value set for ImageMode.
					System.out.println("Illegal image mode value, I can't display image!");
				}
			}
			Dimension d=Toolkit.getDefaultToolkit().getScreenSize();
			URL imageURL;
			Image picture;
		};
		Dimension d=Toolkit.getDefaultToolkit().getScreenSize();
		BigFrame.setSize(d.width,d.height);
		BigFrame.setLocation(0,0);
		BigPan.setBackground(Color.black);
		BigPan.setBounds(0,0,d.width,d.height);
		BigFrame.add(BigPan);
		BigFrame.show();
		
		//If running on linux we don't call this to front as successive calling of panels to front
		//seem to fail.
		
		//if(OS.indexOf("Windows")>=0 || OS.indexOf("Mac")>=0)
			BigFrame.toBack();	
						
		//Set the window to disabled so that the user cannot bring it in front of the installer
		//this does not seem to work on Unix platforms.
			
		BigFrame.setEnabled(false);
	}

	
	/**
	 *  This is the method that is called at uninstall-time.  The DataInput
	 *  instance provides access to any information written at install-time
	 *  with the instance of DataOutput provided by UninstallerProxy.getLogOutput().
	 */
	public void uninstall( UninstallerProxy up ) throws InstallException
	{
		
	}
	
	/**
	 *  This method will be called to display a status message during the
	 *  installation.
	 */
	public String getInstallStatusMessage()
	{
		return "My Action";	// screen will say "Installing... My Action"
	}
	
	/**
	 *  This method will be called to display a status message during the
	 *  uninstall.
	 */
	public String getUninstallStatusMessage()
	{
		return "My Action";	// screen will say "Uninstalling... My Action"
	}
	Window BigFrame;
}